Crate vfs_host

Crate vfs_host 

Modules

filesystem_preopens
filesystem_types

Structs

Fs
Main filesystem structure. See the module-level comment for an overview of the two storage flavours.
FsDescriptorWrapper
Wrapper for fs-core file descriptor stored in ResourceTable. Contains the fd and optionally the path for directory descriptors.
FsDirectoryEntryStreamWrapper
Wrapper for directory entry stream stored in ResourceTable. Caches the directory listing and tracks iteration position.
VfsHostState
Host state that uses fs-core directly for filesystem operations. Multiple instances can share the same VFS via Arc<Fs>.

Constants

O_CREAT
O_RDONLY
File open flags
O_RDWR
O_TRUNC
O_WRONLY

Functions

add_to_linker_with_vfs
Add WASI interfaces to linker with custom VFS filesystem implementation.
convert_fs_error
Helper function to convert fs-core error to WASI error code