Fs

Struct Fs 

pub struct Fs<T = MonotonicCounter>
where T: TimeProvider,
{ /* private fields */ }
Main filesystem structure. See the module-level comment for an overview of the two storage flavours.

Implementations

Source

impl<T> Fs<T>
where T: TimeProvider,

pub fn with_time_provider(time_provider: T) -> Fs<T>

Build an empty filesystem with the supplied time provider. A root directory is created automatically with timestamps populated by the provider.

pub fn open_path(&self, path: &str) -> Result<u32, FsError>

pub fn open_at( &self, dir_fd: u32, path: &str, flags: u32, ) -> Result<u32, FsError>

pub fn open_path_with_flags( &self, path: &str, flags: u32, ) -> Result<u32, FsError>

pub fn write(&self, fd: u32, buf: &[u8]) -> Result<usize, FsError>

pub fn write_at( &self, fd: u32, offset: u64, buf: &[u8], ) -> Result<usize, FsError>

Write data at a specific offset atomically (seek + write in one lock acquisition). Does not touch O_APPEND.

pub fn append_write(&self, fd: u32, buf: &[u8]) -> Result<usize, FsError>

Append data to file atomically (always writes at end of file).

pub fn read(&self, fd: u32, out: &mut [u8]) -> Result<usize, FsError>

pub fn read_at( &self, fd: u32, offset: u64, out: &mut [u8], ) -> Result<usize, FsError>

Read data at a specific offset atomically (seek + read in one lock acquisition).

pub fn ftruncate(&self, fd: u32, size: u64) -> Result<(), FsError>

pub fn close(&self, fd: u32) -> Result<(), FsError>

pub fn stat(&self, path: &str) -> Result<Metadata, FsError>

pub fn fstat(&self, fd: u32) -> Result<Metadata, FsError>

pub fn seek(&self, fd: u32, offset: i64, whence: i32) -> Result<u64, FsError>

pub fn mkdir(&self, path: &str) -> Result<(), FsError>

pub fn mkdir_p(&self, path: &str) -> Result<(), FsError>

pub fn readdir(&self, path: &str) -> Result<Vec<String>, FsError>

pub fn readdir_fd(&self, fd: u32) -> Result<Vec<(String, bool)>, FsError>

Read directory entries from an open file descriptor. Returns a list of (name, is_dir) tuples.

pub fn rmdir(&self, path: &str) -> Result<(), FsError>

Remove an empty directory.

pub fn rename(&self, old_path: &str, new_path: &str) -> Result<(), FsError>

Rename or move a file or directory.

Source

impl Fs

pub fn new() -> Fs

Source

impl<T> Fs<T>
where T: TimeProvider,

pub fn to_snapshot(&self) -> FsSnapshot

Create a snapshot of the current filesystem state.

pub fn from_snapshot(snapshot: FsSnapshot, time_provider: T) -> Fs<T>

Restore filesystem state from a snapshot.